# Man update

> update - In shell mode, checks if the scenarios file bundled with the application is different from the one in current use. If they are different, it asks the user permissions to copy over the file from the distribution and if you would like to keep a backup of the original file.

## Usage

`update`